@@ -44,13 +44,6 @@ synthetic <- clusterlab(centers=5,r=7,sdvec=c(2,2,2,2,2),
                         alphas=c(2,2,2,2,2),centralcluster=FALSE,   
                         numbervec=c(50,50,50,50), seed=123, outliers=10, outlierdist = 20)
 
-## ----fig.width=6,fig.height=6--------------------------------------------
-library(clusterlab)
-synthetic <- clusterlab(centers=5,r=7,sdvec=c(6,6,6,6,6),   
-                        alphas=c(2,2,2,2,2),centralcluster=FALSE,   
-                        numbervec=c(50,50,50,50),rings=5,ringalphas=c(2,4,6,8,10,12),
-                        seed=123) # for a six cluster solution)
-
 ## ----fig.width=6,fig.height=6--------------------------------------------
 library(clusterlab)
 synthetic <- clusterlab(centers=5,r=7,sdvec=c(6,6,6,6,6),   
@@ -58,6 +51,10 @@ synthetic <- clusterlab(centers=5,r=7,sdvec=c(6,6,6,6,6),
                         numbervec=c(50,50,50,50),rings=5,ringalphas=c(2,4,6,8,10,12), 
                         ringthetas = c(30,90,180,0,0,0), seed=123) # for a six cluster solution)
 
+## ----fig.width=6,fig.height=6--------------------------------------------
+library(clusterlab)
+synthetic <- clusterlab(mode='random',centers=12)
+
 ## ----fig.width=6,fig.height=6--------------------------------------------
 head(synthetic$identity_matrix)
 
